(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     61153,       1364]
NotebookOptionsPosition[     61509,       1353]
NotebookOutlinePosition[     61974,       1373]
CellTagsIndexPosition[     61931,       1370]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Fluid Pressure\n",
 StyleBox["Zhelong He, Marek-Jerzy Pindera \nUniversity of Virginia, \
2017-11-1",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center],

Cell["\<\
According to Pascal\[CloseCurlyQuote]s law, a fluid at rest creates a \
pressure p at a point that is the same in all directions. The magnitude of p, \
measured as a force per unit area, depends on the specific mass density \
\[Rho] of the fluid and the depth z of the point from the fluid surface. The \
relationship can be expressed mathematically as\
\>", "Text"],

Cell[TextData[{
 "\t\t\t\t\t\t\t\t\t\t\t\t\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"P", "=", 
    RowBox[{"\[Rho]", " ", "g", " ", "z"}]}], TraditionalForm]]]
}], "Text"],

Cell["\<\
Consider three types of submerged plate and calculate their resultant force, \
including the magnitude, directions and acting point. 
First type is flat plate with constant width, this is the simplest type. \
Since the plate is flat, all the forces thus the resultant force will be \
perpendicular to the plate. The magnitude of pressure will vary linearly \
w.r.t. its depth. Integrating the force directly, we can get the magnitude of \
resultant force, which is equal to the pressure at the centroid times the \
plate area. Integrating the moment w.r.t a reference point, and we can get \
the resultant moment thus determine the acting point of the resultant force. 
Second type is curved plate with constant width. Since the plate is curved, \
the forces direction will vary in different point. Thus we need to decompose \
the force into x direction and y direction, and then do the integration \
separately. Then integrate the moment w.r.t a reference point, and we can get \
the resultant moment thus determine the acting point of the resultant force. \
For a curve like cylinder surface, since every force will pass the axis, thus \
we know resultant force will also pass axis in order to have a zero moment \
w.r.t axis, this brings some benefits for the further determination of acting \
point of resultant force. 
Third type is flat plate with variable width. The magnitude of resultant is \
relatively easy to determine since it will perpendicular to the plate. Also, \
it will equal to the pressure at the centroid times the plate area. \
Integrating the moment w.r.t a reference point, and we can get the resultant \
moment thus determine the acting point of the resultant force. 

For second type there is an easier way to determine its resultant by \
calculating the equivalent loading. For details please see the textbook. 
\
\>", "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`g$$ = 9.8, $CellContext`opt$$ = 
    1, $CellContext`res$$ = 0, $CellContext`resc$$ = 0, $CellContext`resv$$ = 
    0, $CellContext`za$$ = 10, $CellContext`zac$$ = 10, $CellContext`zav$$ = 
    20, $CellContext`\[Theta]d1$$ = 45, $CellContext`\[Theta]d2$$ = 
    0, $CellContext`\[Theta]d3$$ = 30, $CellContext`\[Rho]$$ = 1, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`opt$$], 1, ""}, {1 -> Text[
         Style["Flat Plate + Constant Width", 12]], 2 -> Text[
         Style["Curved Plate + Constant Width", 12]], 3 -> Text[
         Style["Flat Plate + Varied Width", 12]]}}, {{
       Hold[$CellContext`\[Rho]$$], 1, 
       Row[{
         Text[
          Style["Liquid Density (\[Times]", 12]], 
         Text[
          Style[
           Superscript["10", "3"], 12]], 
         Text[
          Style[")", 12]]}]}, 0.8, 1.2, 0.1}, {{
       Hold[$CellContext`g$$], 9.8, 
       Text[
        Style["g", 12]]}, {0 -> Text[
         Style["0", 12]], 9.8 -> Text[
         Style["9.8", 12]], 10 -> Text[
         Style["10", 12]]}}, {{
       Hold[$CellContext`za$$], 10, 
       Row[{
         Text[
          Style[
           Subscript["z", "A"], 12]]}]}, 0, 20, 0.1}, {{
       Hold[$CellContext`\[Theta]d1$$], 45, 
       Text[
        Style["Angle of Plate \[Theta] (\[Degree])", 12]]}, 0, 90, 1}, {{
       Hold[$CellContext`res$$], 0, 
       Text[
        Style["Resultant", 12]]}, {0 -> Text[
         Style["Off", 12]], 1 -> Text[
         Style["On", 12]]}}, {{
       Hold[$CellContext`zac$$], 10, 
       Row[{
         Text[
          Style[
           Subscript["z", "A"], 12]]}]}, 0, 20, 0.1}, {{
       Hold[$CellContext`\[Theta]d2$$], 0, 
       Text[
        Style["Angle of Plate \[Theta] (\[Degree])", 12]]}, 0, 90, 0.1}, {{
       Hold[$CellContext`resc$$], 0, 
       Text[
        Style["Resultant", 12]]}, {0 -> Text[
         Style["Off", 12]], 1 -> Text[
         Style["On", 12]]}}, {{
       Hold[$CellContext`zav$$], 20, 
       Row[{
         Text[
          Style[
           Subscript["z", "A"], 12]]}]}, 10, 30, 0.1}, {{
       Hold[$CellContext`\[Theta]d3$$], 30, 
       Text[
        Style["Angle of Plate \[Theta] (\[Degree])", 12]]}, 0, 90, 1}, {{
       Hold[$CellContext`resv$$], 0, 
       Text[
        Style["Resultant", 12]]}, {0 -> Text[
         Style["Off", 12]], 1 -> Text[
         Style["On", 12]]}}, {
      Hold[
       Column[{
         Row[{
           Manipulate`Place[1]}], 
         Row[{
           Spacer[12], 
           Manipulate`Place[2], 
           Manipulate`Place[3]}], 
         PaneSelector[{1 -> Row[{
              Spacer[111], 
              Manipulate`Place[4], 
              Manipulate`Place[5], 
              Manipulate`Place[6]}], 2 -> Row[{
              Spacer[111], 
              Manipulate`Place[7], 
              Manipulate`Place[8], 
              Manipulate`Place[9]}], 3 -> Row[{
              Spacer[111], 
              Manipulate`Place[10], 
              Manipulate`Place[11], 
              Manipulate`Place[12]}]}, 
          Dynamic[$CellContext`opt$$]]}]], 
      Manipulate`Dump`ThisIsNotAControl}}, Typeset`size$$ = {
    1050., {312., 321.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`opt$79755$$ = 
    False, $CellContext`\[Rho]$79756$$ = 0, $CellContext`g$79757$$ = 
    False, $CellContext`za$79758$$ = 0, $CellContext`\[Theta]d1$79759$$ = 
    0, $CellContext`res$79760$$ = False, $CellContext`zac$79761$$ = 
    0, $CellContext`\[Theta]d2$79762$$ = 0, $CellContext`resc$79763$$ = 
    False, $CellContext`zav$79764$$ = 0, $CellContext`\[Theta]d3$79765$$ = 
    0, $CellContext`resv$79766$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`g$$ = 9.8, $CellContext`opt$$ = 
        1, $CellContext`res$$ = 0, $CellContext`resc$$ = 
        0, $CellContext`resv$$ = 0, $CellContext`za$$ = 
        10, $CellContext`zac$$ = 10, $CellContext`zav$$ = 
        20, $CellContext`\[Theta]d1$$ = 45, $CellContext`\[Theta]d2$$ = 
        0, $CellContext`\[Theta]d3$$ = 30, $CellContext`\[Rho]$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`opt$$, $CellContext`opt$79755$$, False], 
        Hold[$CellContext`\[Rho]$$, $CellContext`\[Rho]$79756$$, 0], 
        Hold[$CellContext`g$$, $CellContext`g$79757$$, False], 
        Hold[$CellContext`za$$, $CellContext`za$79758$$, 0], 
        Hold[$CellContext`\[Theta]d1$$, $CellContext`\[Theta]d1$79759$$, 0], 
        Hold[$CellContext`res$$, $CellContext`res$79760$$, False], 
        Hold[$CellContext`zac$$, $CellContext`zac$79761$$, 0], 
        Hold[$CellContext`\[Theta]d2$$, $CellContext`\[Theta]d2$79762$$, 0], 
        Hold[$CellContext`resc$$, $CellContext`resc$79763$$, False], 
        Hold[$CellContext`zav$$, $CellContext`zav$79764$$, 0], 
        Hold[$CellContext`\[Theta]d3$$, $CellContext`\[Theta]d3$79765$$, 0], 
        Hold[$CellContext`resv$$, $CellContext`resv$79766$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`l$, $CellContext`w$, $CellContext`h$, \
$CellContext`r$, $CellContext`d$, $CellContext`r3$, $CellContext`\[Theta]1$, \
$CellContext`\[Theta]2$, $CellContext`\[Theta]3$, $CellContext`size$, \
$CellContext`font$, $CellContext`opa1$, $CellContext`opa2$, \
$CellContext`opa3$, $CellContext`coord2D$, $CellContext`coord3D$, \
$CellContext`force$, $CellContext`forcefig$, $CellContext`forcepos$, \
$CellContext`flatplate2D$, $CellContext`flatarrow2D$, \
$CellContext`flatplate3D$, $CellContext`flatarrow3D$, \
$CellContext`resforce2D$, $CellContext`resforce3D$, \
$CellContext`resforce23D$, $CellContext`force2$, $CellContext`force2x$, \
$CellContext`force2y$, $CellContext`force2ang$, $CellContext`force2fig$, \
$CellContext`curvedplate2D$, $CellContext`curvedplate3D$, \
$CellContext`curvedarrow2D$, $CellContext`curvedarrow3D$, \
$CellContext`resforce22D$, $CellContext`resforce32D$, \
$CellContext`resforce33D$, $CellContext`force3$, $CellContext`force3fig$, \
$CellContext`force3pos$, $CellContext`variableplate2D$, \
$CellContext`variableplate3D$, $CellContext`variablearrow2D$, \
$CellContext`variablearrow3D$, $CellContext`auxiliary$, $CellContext`dw1$, \
$CellContext`dw2$, $CellContext`dw3$, $CellContext`dw4$, $CellContext`dw5$, \
$CellContext`dw6$, $CellContext`instruction$}, $CellContext`l$ = 
         20; $CellContext`w$ = 10; $CellContext`h$ = 
         0.2; $CellContext`r$ = $CellContext`l$/
          2; $CellContext`d$ = $CellContext`r$; $CellContext`r3$ = 
         0.06 $CellContext`d$; $CellContext`\[Theta]1$ = ($CellContext`\
\[Theta]d1$$/180) 
          Pi; $CellContext`\[Theta]2$ = ($CellContext`\[Theta]d2$$/180) 
          Pi; $CellContext`\[Theta]3$ = ($CellContext`\[Theta]d3$$/180) 
          Pi; $CellContext`size$ = 30; $CellContext`font$ = 
         12; $CellContext`coord2D$ = {
           Thickness[0.002], 
           Arrowheads[0.02], 
           Arrow[{{0, 0}, {0, -$CellContext`l$}}], 
           Arrow[{{0, 0}, {$CellContext`l$, 0}}], 
           Circle[{0, 0}, 0.4], 
           PointSize[0.01], 
           Point[{0, 0}], 
           Text[
           "\!\(\*\nStyleBox[\"x\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {1.05 $CellContext`l$, 0.05 $CellContext`l$}], 
           Text[
           "\!\(\*\nStyleBox[\"y\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {(-0.05) $CellContext`l$, 0.05 $CellContext`l$}], 
           Text[
           "\!\(\*\nStyleBox[\"z\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {(-0.05) $CellContext`l$, (-1.05) \
$CellContext`l$}]}; $CellContext`coord3D$ = {
           Thickness[0.0035], Black, 
           Arrowheads[0.02], 
           
           Arrow[{{0, 0.1 $CellContext`w$, 0.099 $CellContext`l$}, {
              0, 0.1 $CellContext`w$, 0.099 $CellContext`l$} + {
              0.1 $CellContext`l$, 0, 0}}], 
           
           Arrow[{{0, 0.1 $CellContext`w$, 0.099 $CellContext`l$}, {
              0, 0.1 $CellContext`w$, 0.099 $CellContext`l$} + {
              0, (-0.105) $CellContext`w$, 0}}], 
           
           Arrow[{{0, 0.1 $CellContext`w$, 0.099 $CellContext`l$}, {
             0, 0.1 $CellContext`w$, 0}}], 
           Text[
           "\!\(\*\nStyleBox[\"x\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {
            0.105 $CellContext`l$, 0.1 $CellContext`w$, 
             0.099 $CellContext`l$}], 
           Text[
           "\!\(\*\nStyleBox[\"y\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {
            0, (-0.011) $CellContext`w$, 0.0995 $CellContext`l$}], 
           Text[
           "\!\(\*\nStyleBox[\"z\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {
            0, 0.1 $CellContext`w$, (-0.005) $CellContext`l$}]}; \
$CellContext`opa1$ = 
         If[$CellContext`res$$ == 0, 1, 
           0]; $CellContext`force$ = (($CellContext`\[Rho]$$ \
$CellContext`g$$) $CellContext`w$) ($CellContext`za$$ $CellContext`l$ + ((1/
              2) $CellContext`l$^2) 
            Sin[$CellContext`\[Theta]1$]); $CellContext`forcefig$ = 
         If[$CellContext`force$ != 
           0, (2 ($CellContext`force$/(((1 10) $CellContext`w$) (
              20 $CellContext`l$ + (1/
                2) $CellContext`l$^2)))) ($CellContext`l$/4), 
           0]; $CellContext`forcepos$ = 
         If[$CellContext`force$ != 
           0, ((((1/$CellContext`force$) $CellContext`\[Rho]$$) \
$CellContext`g$$) $CellContext`w$) (((1/
               2) $CellContext`za$$) $CellContext`l$^2 + ((1/
               3) $CellContext`l$^3) Sin[$CellContext`\[Theta]1$]), 
           0]; $CellContext`flatplate2D$ = {
           Text[
           "\!\(\*\nStyleBox[\"A\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {(-0.05) $CellContext`l$, (-0.4) \
$CellContext`za$$}], 
           Text[
           "\!\(\*\nStyleBox[\"C\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", ($CellContext`l$/2) {
               Cos[$CellContext`\[Theta]1$], -
               Sin[$CellContext`\[Theta]1$]} + {
             0, (-0.4) $CellContext`za$$ - 0.04 $CellContext`l$}], 
           Lighter[Blue], 
           Thickness[0.005], 
           Translate[
            Rotate[{
              Line[{{0, 0}, {$CellContext`l$, 0}}], Black, 
              Point[{{$CellContext`l$/2, 0}}]}, -$CellContext`\[Theta]1$, {0, 
             0}], {0, (-0.4) $CellContext`za$$}]}; $CellContext`flatarrow2D$ = {
           Opacity[$CellContext`opa1$], 
           Arrowheads[0.02], 
           Thickness[0.003], Red, 
           Arrow[
            
            Table[{(((0.03 $CellContext`\[Rho]$$) $CellContext`g$$) (
                 0.4 $CellContext`za$$ + $CellContext`k 
                  Sin[$CellContext`\[Theta]1$])) {
                 Sin[$CellContext`\[Theta]1$], 
                 Cos[$CellContext`\[Theta]1$]} + {$CellContext`k 
                Cos[$CellContext`\[Theta]1$], (-0.4) $CellContext`za$$ - \
$CellContext`k Sin[$CellContext`\[Theta]1$]}, {$CellContext`k 
               Cos[$CellContext`\[Theta]1$], (-0.4) $CellContext`za$$ - \
$CellContext`k Sin[$CellContext`\[Theta]1$]}}, {$CellContext`k, 
              0, $CellContext`l$, $CellContext`l$/
              10}]]}; $CellContext`resforce2D$ = {
           Opacity[
            Boole[
             And[$CellContext`res$$ == 1, $CellContext`force$ != 0]]], 
           Arrowheads[0.04], 
           Thickness[0.01], Purple, 
           
           Arrow[{{$CellContext`forcepos$ 
               Cos[$CellContext`\[Theta]1$] + $CellContext`forcefig$ 
               Sin[$CellContext`\[Theta]1$], (-0.4) $CellContext`za$$ - \
$CellContext`forcepos$ 
              Sin[$CellContext`\[Theta]1$] + $CellContext`forcefig$ 
               Cos[$CellContext`\[Theta]1$]}, {$CellContext`forcepos$ 
              Cos[$CellContext`\[Theta]1$], (-0.4) $CellContext`za$$ - \
$CellContext`forcepos$ Sin[$CellContext`\[Theta]1$]}}], Black, 
           Thickness[0.003], Dashed, 
           
           Line[{{0, (-0.4) $CellContext`za$$}, {(0.15 $CellContext`l$) 
              Sin[$CellContext`\[Theta]1$], (-0.4) $CellContext`za$$ + (
                0.15 $CellContext`l$) Cos[$CellContext`\[Theta]1$]}}], 
           Arrowheads[{-0.02, 0.02}], 
           Dashing[{}], 
           
           Arrow[{{(0.1 $CellContext`l$) 
              Sin[$CellContext`\[Theta]1$], (-0.4) $CellContext`za$$ + (
                0.1 $CellContext`l$) 
               Cos[$CellContext`\[Theta]1$]}, $CellContext`forcepos$ {
                Cos[$CellContext`\[Theta]1$], -
                Sin[$CellContext`\[Theta]1$]} + {(0.1 $CellContext`l$) 
               Sin[$CellContext`\[Theta]1$], (-0.4) $CellContext`za$$ + (
                 0.1 $CellContext`l$) Cos[$CellContext`\[Theta]1$]}}], 
           Text[
            Style[
             Subscript["l", "F"], $CellContext`font$, 
             Italic], (0.5 $CellContext`forcepos$) {
               Cos[$CellContext`\[Theta]1$], -
               Sin[$CellContext`\[Theta]1$]} + {(0.1 $CellContext`l$) 
              Sin[$CellContext`\[Theta]1$], (-0.4) $CellContext`za$$ + (
                0.1 $CellContext`l$) Cos[$CellContext`\[Theta]1$]} + 
            0.5 {(0.1 $CellContext`l$) 
               Sin[$CellContext`\[Theta]1$], (0.1 $CellContext`l$) 
               Cos[$CellContext`\[Theta]1$]}]}; $CellContext`flatplate3D$ = {
          LightBlue, 
           Translate[
            Rotate[
             
             Cuboid[{0, 0, 0.099 $CellContext`l$}, 
              0.1 {$CellContext`l$, $CellContext`w$, $CellContext`h$} + {
               0, 0, 0.099 $CellContext`l$}], -$CellContext`\[Theta]1$, {
             0, -1, 0}, {0, 0, 0.099 $CellContext`l$}], 
            0.04 {0, 0, -$CellContext`za$$}]}; $CellContext`flatarrow3D$ = {
           Opacity[$CellContext`opa1$], 
           Arrowheads[0.02], 
           Thickness[0.003], Red, 
           Table[
            
            Arrow[{(((0.03 $CellContext`\[Rho]$$) $CellContext`g$$) (
                 0.04 $CellContext`za$$ + $CellContext`k 
                  Sin[$CellContext`\[Theta]1$])) {
                 Sin[$CellContext`\[Theta]1$], 0, 
                 Cos[$CellContext`\[Theta]1$]} + {$CellContext`k 
                Cos[$CellContext`\[Theta]1$], $CellContext`j, (-0.04) \
$CellContext`za$$ - $CellContext`k Sin[$CellContext`\[Theta]1$]} + {
               0, 0, 0.099 $CellContext`l$}, {$CellContext`k 
                Cos[$CellContext`\[Theta]1$], $CellContext`j, (-0.04) \
$CellContext`za$$ - $CellContext`k Sin[$CellContext`\[Theta]1$]} + {
               0, 0, 0.099 $CellContext`l$}}], {$CellContext`j, 0, 
             0.1 $CellContext`w$, 0.025 $CellContext`w$}, {$CellContext`k, 0, 
             0.1 $CellContext`l$, 
             0.01 $CellContext`l$}]}; $CellContext`resforce3D$ = {
           Opacity[
            Boole[
             And[$CellContext`res$$ == 1, $CellContext`force$ != 0]]], 
           Arrowheads[0.04], 
           Thickness[0.01], Purple, 
           
           Arrow[{0.1 {$CellContext`forcefig$ Sin[$CellContext`\[Theta]1$], 
                0, $CellContext`forcefig$ Cos[$CellContext`\[Theta]1$]} + {(
                0.1 $CellContext`forcepos$) Cos[$CellContext`\[Theta]1$], 
               0.05 $CellContext`w$, (-0.04) $CellContext`za$$ - (
                0.1 $CellContext`forcepos$) Sin[$CellContext`\[Theta]1$]} + {
              0, 0, 0.099 $CellContext`l$}, {(0.1 $CellContext`forcepos$) 
               Cos[$CellContext`\[Theta]1$], 
               0.05 $CellContext`w$, (-0.04) $CellContext`za$$ - (
                0.1 $CellContext`forcepos$) Sin[$CellContext`\[Theta]1$]} + {
              0, 0, 0.099 $CellContext`l$}}]}; $CellContext`dw1$ = 
         Graphics[{$CellContext`coord2D$, $CellContext`flatplate2D$, \
$CellContext`flatarrow2D$, $CellContext`resforce2D$}, ImageSize -> 400, 
           PlotRange -> {{(-0.1) $CellContext`size$, $CellContext`size$}, \
{-$CellContext`size$, 0.1 $CellContext`size$}}, Frame -> 
           False]; $CellContext`dw2$ = 
         Graphics3D[{$CellContext`coord3D$, $CellContext`flatplate3D$, \
$CellContext`flatarrow3D$, $CellContext`resforce3D$}, ImageSize -> 300, Boxed -> 
           False, PlotRange -> {{(-0.01) $CellContext`l$, 
              0.11 $CellContext`l$}, {(-0.01) $CellContext`w$, 
              0.11 $CellContext`w$}, {(-0.045) $CellContext`l$, 
              0.12 $CellContext`l$}}]; $CellContext`opa2$ = 
         If[$CellContext`resc$$ == 0, 1, 0]; $CellContext`force2x$ = 
         Integrate[(((((-$CellContext`\[Rho]$$) $CellContext`g$$) \
$CellContext`w$) ($CellContext`zac$$ + $CellContext`r$ 
               Sin[$CellContext`\[Phi]])) $CellContext`r$) 
           Cos[$CellContext`\[Phi]], {$CellContext`\[Phi], $CellContext`\
\[Theta]2$, $CellContext`\[Theta]2$ + Pi/2}]; $CellContext`force2y$ = 
         Integrate[(((($CellContext`\[Rho]$$ $CellContext`g$$) \
$CellContext`w$) ($CellContext`zac$$ + $CellContext`r$ 
               Sin[$CellContext`\[Phi]])) $CellContext`r$) 
           Sin[$CellContext`\[Phi]], {$CellContext`\[Phi], $CellContext`\
\[Theta]2$, $CellContext`\[Theta]2$ + Pi/2}]; $CellContext`force2$ = 
         Sqrt[$CellContext`force2x$^2 + $CellContext`force2y$^2]; \
$CellContext`force2ang$ = If[$CellContext`force2$ != 0, 
           ArcTan[-$CellContext`force2x$, $CellContext`force2y$], 
           0]; $CellContext`force2fig$ = 
         If[$CellContext`force2$ != 0, $CellContext`force2$/4000, 
           0]; $CellContext`curvedplate2D$ = {
           Text[
           "\!\(\*\nStyleBox[\"A\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {$CellContext`r$ + 
             0.05 $CellContext`l$, (-0.4) $CellContext`zac$$}], 
           Lighter[Blue], 
           Thickness[0.005], 
           Translate[
            Rotate[{
              Circle[{0, 0}, $CellContext`r$, {(-Pi)/2, -Pi}], Black, 
              Point[{{0, 0}}]}, $CellContext`\[Theta]2$, {0, 
             0}], {$CellContext`r$, (-0.4) $CellContext`zac$$}]}; \
$CellContext`curvedarrow2D$ = {
           Opacity[$CellContext`opa2$], 
           Arrowheads[0.02], 
           Thickness[0.003], Red, 
           Arrow[
            
            Table[{(((0.03 $CellContext`\[Rho]$$) $CellContext`g$$) (
                 0.4 $CellContext`zac$$ + $CellContext`r$ 
                  Sin[$CellContext`\[Alpha]])) {
                 Cos[$CellContext`\[Alpha]], 
                 Sin[$CellContext`\[Alpha]]} + {(-$CellContext`r$) 
                Cos[$CellContext`\[Alpha]], (-$CellContext`r$) 
                Sin[$CellContext`\[Alpha]]} + {$CellContext`r$, (-0.4) \
$CellContext`zac$$}, {(-$CellContext`r$) 
                Cos[$CellContext`\[Alpha]], (-$CellContext`r$) 
                Sin[$CellContext`\[Alpha]]} + {$CellContext`r$, (-0.4) \
$CellContext`zac$$}}, {$CellContext`\[Alpha], $CellContext`\[Theta]2$, \
$CellContext`\[Theta]2$ + Pi/2, Pi/20}]]}; $CellContext`resforce22D$ = {
           Opacity[
            Boole[
             And[$CellContext`resc$$ == 1, $CellContext`force2$ != 0]]], 
           Arrowheads[0.04], 
           Thickness[0.01], Purple, 
           Arrow[{(-$CellContext`force2fig$) {
                Cos[Pi + $CellContext`force2ang$], 
                Sin[Pi + $CellContext`force2ang$]} + {$CellContext`r$ 
               Cos[Pi + $CellContext`force2ang$], $CellContext`r$ 
               Sin[Pi + $CellContext`force2ang$]} + {$CellContext`r$, (-0.4) \
$CellContext`zac$$}, {$CellContext`r$ 
               Cos[Pi + $CellContext`force2ang$], $CellContext`r$ 
               Sin[Pi + $CellContext`force2ang$]} + {$CellContext`r$, (-0.4) \
$CellContext`zac$$}}], Black, 
           Thickness[0.003], Dashed, 
           
           Line[{{$CellContext`r$, (-0.4) $CellContext`zac$$}, {
             0, (-0.4) $CellContext`zac$$}}], 
           
           Line[{{$CellContext`r$, (-0.4) $CellContext`zac$$}, \
{$CellContext`r$ - $CellContext`r$ 
               Cos[$CellContext`force2ang$], (-$CellContext`r$) 
               Sin[$CellContext`force2ang$]} + {
              0, (-0.4) $CellContext`zac$$}}], 
           Dashing[{}], 
           
           Circle[{$CellContext`r$, (-0.4) $CellContext`zac$$}, 
            0.15 $CellContext`r$, {-Pi + $CellContext`force2ang$, -Pi}], 
           Text[
            Style[
            "\[Beta]", $CellContext`font$], {$CellContext`r$, (-0.4) \
$CellContext`zac$$} + (
              0.25 $CellContext`r$) {-Cos[$CellContext`force2ang$/2], -
               Sin[$CellContext`force2ang$/2]}]}; $CellContext`curvedplate3D$ = 
         ParametricPlot3D[{-Cos[$CellContext`u] + $CellContext`r$/
             10, $CellContext`v, 0.099 $CellContext`l$ - Sin[$CellContext`u] - 
            0.04 $CellContext`zac$$}, {$CellContext`u, \
$CellContext`\[Theta]2$, $CellContext`\[Theta]2$ + Pi/2}, {$CellContext`v, 
            0, $CellContext`w$}, Mesh -> None, PlotStyle -> Directive[
             RGBColor[{30, 144, 255}/255]]]; $CellContext`curvedarrow3D$ = {
           Opacity[$CellContext`opa2$], 
           Arrowheads[0.02], 
           Thickness[0.003], Red, 
           Table[
            
            Arrow[{(((0.03 $CellContext`\[Rho]$$) $CellContext`g$$) (
                 0.04 $CellContext`zac$$ + ($CellContext`r$/10) 
                  Sin[$CellContext`\[Alpha]])) {
                 Cos[$CellContext`\[Alpha]], 0, 
                 Sin[$CellContext`\[Alpha]]} + {$CellContext`r$/
                 10 - ($CellContext`r$/10) 
                Cos[$CellContext`\[Alpha]], $CellContext`j, (-0.04) \
$CellContext`zac$$ - ($CellContext`r$/10) Sin[$CellContext`\[Alpha]]} + {
               0, 0, 0.099 $CellContext`l$}, {$CellContext`r$/
                 10 - ($CellContext`r$/10) 
                Cos[$CellContext`\[Alpha]], $CellContext`j, (-0.04) \
$CellContext`zac$$ - ($CellContext`r$/10) Sin[$CellContext`\[Alpha]]} + {
               0, 0, 0.099 $CellContext`l$}}], {$CellContext`j, 0, 
             0.1 $CellContext`w$, 
             0.025 $CellContext`w$}, {$CellContext`\[Alpha], $CellContext`\
\[Theta]2$, $CellContext`\[Theta]2$ + Pi/2, Pi/
             20}]}; $CellContext`resforce23D$ = {
           Opacity[
            Boole[
             And[$CellContext`resc$$ == 1, $CellContext`force2$ != 0]]], 
           Arrowheads[0.04], 
           Thickness[0.01], Purple, 
           Arrow[{(0.1 $CellContext`force2fig$) {
                Cos[$CellContext`force2ang$], 0, 
                Sin[$CellContext`force2ang$]} + {$CellContext`r$/
                10 - ($CellContext`r$/10) Cos[$CellContext`force2ang$], 
               0.05 $CellContext`w$, (-0.04) $CellContext`zac$$ - \
($CellContext`r$/10) Sin[$CellContext`force2ang$]} + {
              0, 0, 0.099 $CellContext`l$}, {$CellContext`r$/
                10 - ($CellContext`r$/10) Cos[$CellContext`force2ang$], 
               0.05 $CellContext`w$, (-0.04) $CellContext`zac$$ - \
($CellContext`r$/10) Sin[$CellContext`force2ang$]} + {
              0, 0, 0.099 $CellContext`l$}}]}; $CellContext`dw3$ = 
         Graphics[{$CellContext`coord2D$, $CellContext`curvedplate2D$, \
$CellContext`curvedarrow2D$, Null, $CellContext`resforce22D$}, ImageSize -> 
           400, PlotRange -> {{(-0.1) $CellContext`size$, \
$CellContext`size$}, {-$CellContext`size$, 0.1 $CellContext`size$}}, Frame -> 
           False]; $CellContext`dw4$ = 
         Graphics3D[{$CellContext`coord3D$, $CellContext`curvedarrow3D$, \
$CellContext`resforce23D$}, ImageSize -> 300, Boxed -> False, 
           PlotRange -> {{(-0.01) $CellContext`l$, 
              0.11 $CellContext`l$}, {(-0.01) $CellContext`w$, 
              0.11 $CellContext`w$}, {(-0.045) $CellContext`l$, 
              0.12 $CellContext`l$}}]; $CellContext`opa3$ = 
         If[$CellContext`resv$$ == 0, 1, 
           0]; $CellContext`force3$ = ((($CellContext`\[Rho]$$ \
$CellContext`g$$) $CellContext`zav$$) 
           Pi) ($CellContext`d$/2)^2; $CellContext`force3fig$ = 
         If[$CellContext`force3$ != 0, $CellContext`force3$/4000, 
           0]; $CellContext`force3pos$ = 
         If[$CellContext`force3$ != 
           0, (($CellContext`d$/2)^2/(4 $CellContext`zav$$)) 
           Sin[$CellContext`\[Theta]3$], 0]; $CellContext`variableplate2D$ = {
           Text[
           "\!\(\*\nStyleBox[\"A\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {
            0.95 $CellContext`d$, (-0.55) $CellContext`d$ - 
             0.4 $CellContext`zav$$ + 4}], 
           Lighter[Blue], 
           Thickness[0.005], 
           Translate[
            Rotate[
             
             Line[{{0, 
               0}, {$CellContext`d$, 
                0}}], -$CellContext`\[Theta]3$, {$CellContext`d$/2, 0}], {
            0.5 $CellContext`d$, (-0.5) $CellContext`d$ - 
             0.4 $CellContext`zav$$ + 4}], Black, 
           PointSize[0.01], 
           
           Point[{$CellContext`d$, (-0.5) $CellContext`d$ - 
             0.4 $CellContext`zav$$ + 4}]}; $CellContext`variablearrow2D$ = {
           Opacity[$CellContext`opa3$], 
           Arrowheads[0.02], 
           Thickness[0.003], Red, 
           Arrow[
            
            Table[{(((0.03 $CellContext`\[Rho]$$) $CellContext`g$$) (
                 0.5 $CellContext`zav$$ + $CellContext`k 
                  Sin[$CellContext`\[Theta]3$])) {
                 Sin[$CellContext`\[Theta]3$], 
                 
                 Cos[$CellContext`\[Theta]3$]} + {$CellContext`d$ + \
$CellContext`k Cos[$CellContext`\[Theta]3$], (-0.5) $CellContext`d$ - 
                0.4 $CellContext`zav$$ + 4 - $CellContext`k 
                Sin[$CellContext`\[Theta]3$]}, {$CellContext`d$ + \
$CellContext`k Cos[$CellContext`\[Theta]3$], (-0.5) $CellContext`d$ - 
               0.4 $CellContext`zav$$ + 4 - $CellContext`k 
               Sin[$CellContext`\[Theta]3$]}}, {$CellContext`k, \
(-$CellContext`d$)/2, $CellContext`d$/2, $CellContext`d$/
              10}]]}; $CellContext`resforce32D$ = {
           Opacity[
            Boole[
             And[$CellContext`resv$$ == 1, $CellContext`force3$ != 0]]], 
           Arrowheads[0.04], 
           Thickness[0.01], Purple, 
           Arrow[{$CellContext`force3fig$ {
                Sin[$CellContext`\[Theta]3$], 
                
                Cos[$CellContext`\[Theta]3$]} + {$CellContext`d$ + \
$CellContext`force3pos$ Cos[$CellContext`\[Theta]3$], (-0.5) $CellContext`d$ - 
               0.4 $CellContext`zav$$ + 4 - $CellContext`force3pos$ 
               Sin[$CellContext`\[Theta]3$]}, {$CellContext`d$ + \
$CellContext`force3pos$ Cos[$CellContext`\[Theta]3$], (-0.5) $CellContext`d$ - 
              0.4 $CellContext`zav$$ + 4 - $CellContext`force3pos$ 
              Sin[$CellContext`\[Theta]3$]}}]}; $CellContext`auxiliary$ = {
           Opacity[
            Boole[
             
             And[$CellContext`resv$$ == 1, $CellContext`force3$ != 
              0, $CellContext`force3pos$ != 0]]], Black, 
           Thickness[0.002], 
           
           Line[{{$CellContext`d$, (-0.5) $CellContext`d$ - 
              0.4 $CellContext`zav$$ + 
              4}, {$CellContext`d$, (-0.5) $CellContext`d$ - 
               0.4 $CellContext`zav$$ + 4} - ($CellContext`d$/5) {
               Sin[$CellContext`\[Theta]3$], 
               Cos[$CellContext`\[Theta]3$]}}], 
           
           Line[{{$CellContext`d$, (-0.5) $CellContext`d$ - 
               0.4 $CellContext`zav$$ + 4} + $CellContext`force3pos$ {
                Cos[$CellContext`\[Theta]3$], -
                Sin[$CellContext`\[Theta]3$]}, {$CellContext`d$, (-0.5) \
$CellContext`d$ - 0.4 $CellContext`zav$$ + 4} + $CellContext`force3pos$ {
                Cos[$CellContext`\[Theta]3$], -
                Sin[$CellContext`\[Theta]3$]} - ($CellContext`d$/5) {
               Sin[$CellContext`\[Theta]3$], 
               Cos[$CellContext`\[Theta]3$]}}], Red, 
           Thickness[0.004], 
           Arrowheads[0.02], 
           
           Arrow[{{$CellContext`d$, (-0.5) $CellContext`d$ - 
               0.4 $CellContext`zav$$ + 4} - ($CellContext`d$/10) {
               Sin[$CellContext`\[Theta]3$], 
               Cos[$CellContext`\[Theta]3$]} + ($CellContext`d$/
               5) {-Cos[$CellContext`\[Theta]3$], 
                
                Sin[$CellContext`\[Theta]3$]}, {$CellContext`d$, (-0.5) \
$CellContext`d$ - 0.4 $CellContext`zav$$ + 4} - ($CellContext`d$/10) {
               Sin[$CellContext`\[Theta]3$], 
               Cos[$CellContext`\[Theta]3$]}}], 
           Arrow[{$CellContext`force3pos$ {
                Cos[$CellContext`\[Theta]3$], -
                Sin[$CellContext`\[Theta]3$]} + {$CellContext`d$, (-0.5) \
$CellContext`d$ - 0.4 $CellContext`zav$$ + 4} - ($CellContext`d$/10) {
               Sin[$CellContext`\[Theta]3$], 
               Cos[$CellContext`\[Theta]3$]} - ($CellContext`d$/
              5) {-Cos[$CellContext`\[Theta]3$], 
               Sin[$CellContext`\[Theta]3$]}, $CellContext`force3pos$ {
                Cos[$CellContext`\[Theta]3$], -
                Sin[$CellContext`\[Theta]3$]} + {$CellContext`d$, (-0.5) \
$CellContext`d$ - 0.4 $CellContext`zav$$ + 4} - ($CellContext`d$/10) {
               Sin[$CellContext`\[Theta]3$], 
               Cos[$CellContext`\[Theta]3$]}}], Black, 
           Text[
            Style[
             Subscript["d", "F"], 10, Bold, 
             Italic], {$CellContext`d$, (-0.5) $CellContext`d$ - 
              0.4 $CellContext`zav$$ + 4} - ($CellContext`d$/5) {
              Sin[$CellContext`\[Theta]3$], 
              Cos[$CellContext`\[Theta]3$]} + ($CellContext`d$/8) {
               Cos[$CellContext`\[Theta]3$], -
               Sin[$CellContext`\[Theta]3$]}]}; $CellContext`variableplate3D$ = \
{LightBlue, 
           Translate[
            Rotate[
             
             Cylinder[{{0, 0, ((-1)/30) $CellContext`r3$}, {
               0, 0, (1/
                 30) $CellContext`r3$}}, $CellContext`r3$], -$CellContext`\
\[Theta]3$, {0, -1, 0}, {0, 0, 0}], {0.1 $CellContext`d$, 0, 0} + {
             0, 0.05 $CellContext`d$, 0} + {0, 0, 0.099 $CellContext`l$} - {
            0, 0, 0.06 $CellContext`d$} + 0.04 {0, 0, -$CellContext`zav$$} + 
            0.4 {0, 0, 1}]}; $CellContext`variablearrow3D$ = {
           Opacity[$CellContext`opa3$], 
           Arrowheads[0.02], 
           Thickness[0.005], Red, 
           Translate[
            Rotate[{
              
              Arrow[{{-$CellContext`r3$, 0, 
                  0} + (((
                    0.002 $CellContext`\[Rho]$$) $CellContext`g$$) \
($CellContext`zav$$ - $CellContext`d$ Sin[$CellContext`\[Theta]3$])) {0, 0, 
                  1}, {-$CellContext`r3$, 0, 0}}], 
              Arrow[
               
               Table[{{((-4)/5) $CellContext`r3$, $CellContext`j, 
                   0} + (((
                    0.002 $CellContext`\[Rho]$$) $CellContext`g$$) \
($CellContext`zav$$ - ((4/5) $CellContext`d$) Sin[$CellContext`\[Theta]3$])) {
                   0, 0, 1}, {((-4)/5) $CellContext`r3$, $CellContext`j, 
                  0}}, {$CellContext`j, -
                 Sqrt[$CellContext`r3$^2 - ((4/5) $CellContext`r3$)^2], 
                 Sqrt[$CellContext`r3$^2 - ((4/5) $CellContext`r3$)^2], 
                 2 (Sqrt[$CellContext`r3$^2 - ((4/5) $CellContext`r3$)^2]/
                  4)}]], 
              Arrow[
               
               Table[{{((-3)/5) $CellContext`r3$, $CellContext`j, 
                   0} + (((
                    0.002 $CellContext`\[Rho]$$) $CellContext`g$$) \
($CellContext`zav$$ - ((3/5) $CellContext`d$) Sin[$CellContext`\[Theta]3$])) {
                   0, 0, 1}, {((-3)/5) $CellContext`r3$, $CellContext`j, 
                  0}}, {$CellContext`j, -
                 Sqrt[$CellContext`r3$^2 - ((3/5) $CellContext`r3$)^2], 
                 Sqrt[$CellContext`r3$^2 - ((3/5) $CellContext`r3$)^2], 
                 2 (Sqrt[$CellContext`r3$^2 - ((3/5) $CellContext`r3$)^2]/
                  4)}]], 
              Arrow[
               
               Table[{{((-2)/5) $CellContext`r3$, $CellContext`j, 
                   0} + (((
                    0.002 $CellContext`\[Rho]$$) $CellContext`g$$) \
($CellContext`zav$$ - ((2/5) $CellContext`d$) Sin[$CellContext`\[Theta]3$])) {
                   0, 0, 1}, {((-2)/5) $CellContext`r3$, $CellContext`j, 
                  0}}, {$CellContext`j, -
                 Sqrt[$CellContext`r3$^2 - ((2/5) $CellContext`r3$)^2], 
                 Sqrt[$CellContext`r3$^2 - ((2/5) $CellContext`r3$)^2], 
                 2 (Sqrt[$CellContext`r3$^2 - ((2/5) $CellContext`r3$)^2]/
                  4)}]], 
              Arrow[
               
               Table[{{((-1)/5) $CellContext`r3$, $CellContext`j, 
                   0} + (((
                    0.002 $CellContext`\[Rho]$$) $CellContext`g$$) \
($CellContext`zav$$ - ((1/5) $CellContext`d$) Sin[$CellContext`\[Theta]3$])) {
                   0, 0, 1}, {((-1)/5) $CellContext`r3$, $CellContext`j, 
                  0}}, {$CellContext`j, -
                 Sqrt[$CellContext`r3$^2 - ((1/5) $CellContext`r3$)^2], 
                 Sqrt[$CellContext`r3$^2 - ((1/5) $CellContext`r3$)^2], 
                 2 (Sqrt[$CellContext`r3$^2 - ((1/5) $CellContext`r3$)^2]/
                  4)}]], 
              Arrow[
               
               Table[{{
                  0, $CellContext`j, 
                   0} + (((
                    0.002 $CellContext`\[Rho]$$) $CellContext`g$$) \
$CellContext`zav$$) {0, 0, 1}, {
                 0, $CellContext`j, 
                  0}}, {$CellContext`j, -$CellContext`r3$, $CellContext`r3$, 
                 2 ($CellContext`r3$/4)}]], 
              Arrow[
               
               Table[{{(1/5) $CellContext`r3$, $CellContext`j, 
                   0} + (((
                    0.002 $CellContext`\[Rho]$$) $CellContext`g$$) \
($CellContext`zav$$ + ((1/5) $CellContext`d$) Sin[$CellContext`\[Theta]3$])) {
                   0, 0, 1}, {(1/5) $CellContext`r3$, $CellContext`j, 
                  0}}, {$CellContext`j, -
                 Sqrt[$CellContext`r3$^2 - ((1/5) $CellContext`r3$)^2], 
                 Sqrt[$CellContext`r3$^2 - ((1/5) $CellContext`r3$)^2], 
                 2 (Sqrt[$CellContext`r3$^2 - ((1/5) $CellContext`r3$)^2]/
                  4)}]], 
              Arrow[
               
               Table[{{(2/5) $CellContext`r3$, $CellContext`j, 
                   0} + (((
                    0.002 $CellContext`\[Rho]$$) $CellContext`g$$) \
($CellContext`zav$$ + ((2/5) $CellContext`d$) Sin[$CellContext`\[Theta]3$])) {
                   0, 0, 1}, {(2/5) $CellContext`r3$, $CellContext`j, 
                  0}}, {$CellContext`j, -
                 Sqrt[$CellContext`r3$^2 - ((2/5) $CellContext`r3$)^2], 
                 Sqrt[$CellContext`r3$^2 - ((2/5) $CellContext`r3$)^2], 
                 2 (Sqrt[$CellContext`r3$^2 - ((2/5) $CellContext`r3$)^2]/
                  4)}]], 
              Arrow[
               
               Table[{{(3/5) $CellContext`r3$, $CellContext`j, 
                   0} + (((
                    0.002 $CellContext`\[Rho]$$) $CellContext`g$$) \
($CellContext`zav$$ + ((3/5) $CellContext`d$) Sin[$CellContext`\[Theta]3$])) {
                   0, 0, 1}, {(3/5) $CellContext`r3$, $CellContext`j, 
                  0}}, {$CellContext`j, -
                 Sqrt[$CellContext`r3$^2 - ((3/5) $CellContext`r3$)^2], 
                 Sqrt[$CellContext`r3$^2 - ((3/5) $CellContext`r3$)^2], 
                 2 (Sqrt[$CellContext`r3$^2 - ((3/5) $CellContext`r3$)^2]/
                  4)}]], 
              Arrow[
               
               Table[{{(4/5) $CellContext`r3$, $CellContext`j, 
                   0} + (((
                    0.002 $CellContext`\[Rho]$$) $CellContext`g$$) \
($CellContext`zav$$ + ((4/5) $CellContext`d$) Sin[$CellContext`\[Theta]3$])) {
                   0, 0, 1}, {(4/5) $CellContext`r3$, $CellContext`j, 
                  0}}, {$CellContext`j, -
                 Sqrt[$CellContext`r3$^2 - ((4/5) $CellContext`r3$)^2], 
                 Sqrt[$CellContext`r3$^2 - ((4/5) $CellContext`r3$)^2], 
                 2 (Sqrt[$CellContext`r3$^2 - ((4/5) $CellContext`r3$)^2]/
                  4)}]], 
              
              Arrow[{{$CellContext`r3$, 0, 
                  0} + (((
                    0.002 $CellContext`\[Rho]$$) $CellContext`g$$) \
($CellContext`zav$$ + $CellContext`d$ Sin[$CellContext`\[Theta]3$])) {0, 0, 
                  1}, {$CellContext`r3$, 0, 0}}]}, -$CellContext`\[Theta]3$, {
             0, -1, 0}, {0, 0, 0}], {0.1 $CellContext`d$, 0, 0} + {
             0, 0.05 $CellContext`d$, 0} + {0, 0, 0.099 $CellContext`l$} - {
            0, 0, 0.06 $CellContext`d$} + 0.04 {0, 0, -$CellContext`zav$$} + 
            0.4 {0, 0, 1}]}; $CellContext`resforce33D$ = {
           Opacity[
            Boole[
             And[$CellContext`resv$$ == 1, $CellContext`force3$ != 0]]], 
           Translate[
            Rotate[{
              Arrowheads[0.04], 
              Thickness[0.01], Purple, 
              
              Arrow[{{0, 0, 0.002 $CellContext`d$} + (
                  0.1 $CellContext`force3pos$) {1, 0, 0} + (
                  0.1 $CellContext`force3fig$) {0, 0, 1}, {
                 0, 0, 0.002 $CellContext`d$} + (
                  0.1 $CellContext`force3pos$) {1, 0, 0}}], Black, Dashed, 
              
              Line[{{(-0.06) $CellContext`d$, 0, 0}, {
                0.06 $CellContext`d$, 0, 0}}], 
              
              Line[{{0, (-0.036) $CellContext`d$, 0}, {
                0, 0.06 $CellContext`d$, 0}}], 
              PointSize[0.01], 
              
              Point[{{0, 0, 
                 0.002 $CellContext`d$}}]}, -$CellContext`\[Theta]3$, {0, -1, 
             0}, {0, 0, 0}], {0.1 $CellContext`d$, 0, 0} + {
             0, 0.05 $CellContext`d$, 0} + {0, 0, 0.099 $CellContext`l$} - {
            0, 0, 0.06 $CellContext`d$} + 0.04 {0, 0, -$CellContext`zav$$} + 
            0.4 {0, 0, 1}]}; $CellContext`dw5$ = 
         Graphics[{$CellContext`coord2D$, $CellContext`variableplate2D$, \
$CellContext`variablearrow2D$, $CellContext`resforce32D$, \
$CellContext`auxiliary$}, ImageSize -> 400, 
           PlotRange -> {{(-0.1) $CellContext`size$, $CellContext`size$}, \
{-$CellContext`size$, 0.1 $CellContext`size$}}, Frame -> 
           False]; $CellContext`dw6$ = 
         Graphics3D[{$CellContext`coord3D$, $CellContext`variableplate3D$, \
$CellContext`variablearrow3D$, $CellContext`resforce33D$}, ImageSize -> 300, 
           Boxed -> False, 
           PlotRange -> {{(-0.01) $CellContext`l$, 
              0.11 $CellContext`l$}, {(-0.01) $CellContext`w$, 
              0.11 $CellContext`w$}, {(-0.045) $CellContext`l$, 
              0.12 $CellContext`l$}}]; $CellContext`instruction$ = 
         Switch[$CellContext`opt$$, 1, 
           Switch[$CellContext`res$$, 0, "", 1, 
            Column[{
              Row[{
                Text[
                 Style["F", $CellContext`font$, Italic]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style[
                 "\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\(\\ \
\)\(L\)\)]\)\[Rho]gw (", $CellContext`font$]], 
                Text[
                 Style[
                  Subscript["z", "A"], $CellContext`font$]], 
                Text[
                 Style["+", $CellContext`font$]], 
                Text[
                 Style["lsin\[Theta]) dl", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["\[Rho]g(", $CellContext`font$]], 
                Text[
                 Style[
                  Subscript["z", "A"], $CellContext`font$]], 
                Text[
                 Style[
                 " +\!\(\*FractionBox[\(1\), \(2\)]\)L", $CellContext`font$]], 
                Text[
                 Style["sin\[Theta])wL", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["\[Rho]g", $CellContext`font$]], 
                Text[
                 Style[
                  Subscript["z", "C"], $CellContext`font$]], 
                Text[
                 Style["wL", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style[
                  
                  ScientificForm[$CellContext`force$ 10^3, 
                   3], $CellContext`font$, Italic]], 
                Spacer[50], 
                Text[
                 Style["Width: w=", $CellContext`font$, Italic]], 
                Text[
                 Style[
                  NumberForm[$CellContext`w$, {3, 2}], $CellContext`font$, 
                  Italic]], 
                Spacer[50], 
                Text[
                 Style["Length: L=", $CellContext`font$, Italic]], 
                Text[
                 Style[
                  NumberForm[$CellContext`l$, {3, 2}], $CellContext`font$, 
                  Italic]]}], 
              Row[{
                Text[
                 Style[
                  Subscript["l", "F"], $CellContext`font$, Italic]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style[
                 "\!\(\*FractionBox[\(1\), \(F\)]\)", $CellContext`font$]], 
                Text[
                 Style[
                 "\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(\(\\ \
\)\(L\)\)]\)\[Rho]gwl (", $CellContext`font$]], 
                Text[
                 Style[
                  Subscript["z", "A"], $CellContext`font$]], 
                Text[
                 Style["+", $CellContext`font$]], 
                Text[
                 Style["lsin\[Theta]) dl", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style[
                 "\!\(\*FractionBox[\(1\), \(F\)]\)", $CellContext`font$]], 
                Text[
                 Style["\[Rho]gw(", $CellContext`font$]], 
                Text[
                 Style[
                 "\!\(\*FractionBox[\(1\), \(2\)]\)", $CellContext`font$]], 
                Text[
                 Style[
                  Subscript["z", "A"], $CellContext`font$]], 
                Text[
                 Style[
                  Superscript["L", "2"], $CellContext`font$]], 
                Text[
                 Style["+", $CellContext`font$]], 
                Text[
                 Style[
                 "\!\(\*FractionBox[\(1\), \(3\)]\)", $CellContext`font$]], 
                Text[
                 Style[
                  Superscript["L", "3"], $CellContext`font$]], 
                Text[
                 Style["sin\[Theta])", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style[
                  
                  NumberForm[$CellContext`forcepos$, {7, 
                   2}], $CellContext`font$, Italic]]}]}]], 2, 
           Switch[$CellContext`resc$$, 0, "", 1, 
            Column[{
              Row[{
                Text[
                 Style[
                  Subscript["F", "x"], $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style[
                 "\!\(\*SubsuperscriptBox[\(\[Integral]\), \(\[Theta]\), \(\
\[Theta] + \[Pi]/2\)]\)-\[Rho]gw(", $CellContext`font$]], 
                Text[
                 Style[
                  Subscript["z", "A"], $CellContext`font$]], 
                Text[
                 Style["+", $CellContext`font$]], 
                Text[
                 Style[
                 "rsin\[Alpha])rcos\[Alpha] d\[Alpha]", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["-\[Rho]gwr[", $CellContext`font$]], 
                Text[
                 Style[
                  Subscript["z", "A"], $CellContext`font$]], 
                Text[
                 Style[
                 "(cos\[Theta]-sin\[Theta])+\!\(\*FractionBox[\(1\), \
\(2\)]\)rcos2\[Theta]]", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style[
                  
                  ScientificForm[$CellContext`force2x$ 10^3, 
                   3], $CellContext`font$, Italic]]}], 
              Row[{
                Text[
                 Style[
                  Subscript["F", "z"], $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style[
                 "\!\(\*SubsuperscriptBox[\(\[Integral]\), \(\[Theta]\), \(\
\[Theta] + \[Pi]/2\)]\)\[Rho]gw(", $CellContext`font$]], 
                Text[
                 Style[
                  Subscript["z", "A"], $CellContext`font$]], 
                Text[
                 Style["+", $CellContext`font$]], 
                Text[
                 Style[
                 "rsin\[Alpha])rsin\[Alpha] d\[Alpha]", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["\[Rho]gwr[", $CellContext`font$]], 
                Text[
                 Style[
                  Subscript["z", "A"], $CellContext`font$]], 
                Text[
                 Style[
                 "(sin\[Theta]+cos\[Theta])+\!\(\*FractionBox[\(1\), \
\(4\)]\)r(\[Pi]+2sin2\[Theta])]", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style[
                  
                  ScientificForm[$CellContext`force2y$ 10^3, 
                   3], $CellContext`font$, Italic]]}], 
              Row[{
                Text[
                 Style["F", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style[
                 "\!\(\*SqrtBox[\(\*SubsuperscriptBox[\(F\), \(x\), \(2\)] + \
\*SubsuperscriptBox[\(F\), \(z\), \(2\)]\)]\)", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Text[
                 Style[
                  
                  ScientificForm[$CellContext`force2$ 10^3, 
                   3], $CellContext`font$, Italic]], 
                Spacer[50], 
                Text[
                 Style["\[Beta]", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["ArcTan", $CellContext`font$]], 
                Text[
                 Style["(-", $CellContext`font$]], 
                Text[
                 Style[
                  Subscript["F", "z"], $CellContext`font$]], 
                Text[
                 Style["/", $CellContext`font$]], 
                Text[
                 Style[
                  Subscript["F", "x"], $CellContext`font$]], 
                Text[
                 Style[")", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style[
                  NumberForm[
                   N[$CellContext`force2ang$ (180/Pi)], {4, 
                   2}], $CellContext`font$, Italic]], 
                Text[
                 Style["\[Degree]", $CellContext`font$]], 
                Spacer[50], 
                Text[
                 Style["Width: w=", $CellContext`font$, Italic]], 
                Text[
                 Style[
                  NumberForm[$CellContext`w$, {3, 2}], $CellContext`font$, 
                  Italic]], 
                Spacer[50], 
                Text[
                 Style["Radius: r=", $CellContext`font$, Italic]], 
                Text[
                 Style[
                  NumberForm[$CellContext`r$, {3, 2}], $CellContext`font$, 
                  Italic]]}]}]], 3, 
           Switch[$CellContext`resv$$, 0, "", 1, 
            Column[{
              Row[{
                Text[
                 Style["F", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["\[Integral]\[Rho]gz dA", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["\[Rho]g", $CellContext`font$]], 
                Text[
                 Style[
                  Subscript["z", "A"], $CellContext`font$]], 
                Text[
                 Style["A", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["\[Rho]g", $CellContext`font$]], 
                Text[
                 Style[
                  Subscript["z", "A"], $CellContext`font$]], 
                Text[
                 Style["\[Pi]", $CellContext`font$]], 
                Text[
                 Style[
                  Superscript["r", "2"], $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style[
                  
                  ScientificForm[$CellContext`force3$ 10^3, 
                   3], $CellContext`font$, Italic]], 
                Spacer[200], 
                Text[
                 Style["Radius: r=", $CellContext`font$, Italic]], 
                Text[
                 Style[
                  NumberForm[$CellContext`d$/2, {3, 2}], $CellContext`font$, 
                  Italic]]}], 
              Row[{
                Text[
                 Style[
                  Subscript["d", "F"], $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["M / F", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style[
                 "(\!\(\*SubsuperscriptBox[\(\[Integral]\), \(o\), \(r\)]\)\!\
\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \(2  \[Pi]\)]\)\[Rho]g(", \
$CellContext`font$]], 
                Text[
                 Style[
                  Subscript["z", "A"], $CellContext`font$]], 
                Text[
                 Style[
                 "-\[Zeta]cos\[Alpha]sin\[Theta])", $CellContext`font$]], 
                Text[
                 Style[
                  Superscript["\[Zeta]", "2"], $CellContext`font$]], 
                Text[
                 Style["cos\[Alpha]d\[Zeta]d\[Alpha])", $CellContext`font$]], 
                Text[
                 Style[" / F", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style["=", $CellContext`font$]], 
                Spacer[4], 
                Text[
                 Style[
                  NumberForm[
                   N[$CellContext`force3pos$], {4, 2}], $CellContext`font$, 
                  Italic]]}]}]]]; Switch[$CellContext`opt$$, 1, 
          Column[{
            
            Row[{$CellContext`dw1$, $CellContext`dw2$}], \
$CellContext`instruction$}], 2, 
          Column[{
            Row[{$CellContext`dw3$, 
              
              Show[{$CellContext`dw4$, $CellContext`curvedplate3D$}]}], \
$CellContext`instruction$}], 3, 
          Column[{
            
            Row[{$CellContext`dw5$, $CellContext`dw6$}], \
$CellContext`instruction$}]]], 
      "Specifications" :> {{{$CellContext`opt$$, 1, ""}, {1 -> Text[
            Style["Flat Plate + Constant Width", 12]], 2 -> Text[
            Style["Curved Plate + Constant Width", 12]], 3 -> Text[
            Style["Flat Plate + Varied Width", 12]]}, ControlType -> 
         PopupMenu, ControlPlacement -> 1}, {{$CellContext`\[Rho]$$, 1, 
          Row[{
            Text[
             Style["Liquid Density (\[Times]", 12]], 
            Text[
             Style[
              Superscript["10", "3"], 12]], 
            Text[
             Style[")", 12]]}]}, 0.8, 1.2, 0.1, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 2}, {{$CellContext`g$$, 9.8, 
          Text[
           Style["g", 12]]}, {0 -> Text[
            Style["0", 12]], 9.8 -> Text[
            Style["9.8", 12]], 10 -> Text[
            Style["10", 12]]}, ControlType -> RadioButton, ControlPlacement -> 
         3}, {{$CellContext`za$$, 10, 
          Row[{
            Text[
             Style[
              Subscript["z", "A"], 12]]}]}, 0, 20, 0.1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         4}, {{$CellContext`\[Theta]d1$$, 45, 
          Text[
           Style["Angle of Plate \[Theta] (\[Degree])", 12]]}, 0, 90, 1, 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         5}, {{$CellContext`res$$, 0, 
          Text[
           Style["Resultant", 12]]}, {0 -> Text[
            Style["Off", 12]], 1 -> Text[
            Style["On", 12]]}, ControlType -> RadioButton, ControlPlacement -> 
         6}, {{$CellContext`zac$$, 10, 
          Row[{
            Text[
             Style[
              Subscript["z", "A"], 12]]}]}, 0, 20, 0.1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         7}, {{$CellContext`\[Theta]d2$$, 0, 
          Text[
           Style["Angle of Plate \[Theta] (\[Degree])", 12]]}, 0, 90, 0.1, 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         8}, {{$CellContext`resc$$, 0, 
          Text[
           Style["Resultant", 12]]}, {0 -> Text[
            Style["Off", 12]], 1 -> Text[
            Style["On", 12]]}, ControlType -> RadioButton, ControlPlacement -> 
         9}, {{$CellContext`zav$$, 20, 
          Row[{
            Text[
             Style[
              Subscript["z", "A"], 12]]}]}, 10, 30, 0.1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         10}, {{$CellContext`\[Theta]d3$$, 30, 
          Text[
           Style["Angle of Plate \[Theta] (\[Degree])", 12]]}, 0, 90, 1, 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         11}, {{$CellContext`resv$$, 0, 
          Text[
           Style["Resultant", 12]]}, {0 -> Text[
            Style["Off", 12]], 1 -> Text[
            Style["On", 12]]}, ControlType -> RadioButton, ControlPlacement -> 
         12}, 
        Column[{
          Row[{
            Manipulate`Place[1]}], 
          Row[{
            Spacer[12], 
            Manipulate`Place[2], 
            Manipulate`Place[3]}], 
          PaneSelector[{1 -> Row[{
               Spacer[111], 
               Manipulate`Place[4], 
               Manipulate`Place[5], 
               Manipulate`Place[6]}], 2 -> Row[{
               Spacer[111], 
               Manipulate`Place[7], 
               Manipulate`Place[8], 
               Manipulate`Place[9]}], 3 -> Row[{
               Spacer[111], 
               Manipulate`Place[10], 
               Manipulate`Place[11], 
               Manipulate`Place[12]}]}, 
           Dynamic[$CellContext`opt$$]]}]}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{1122., {418., 427.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.5 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 199, 7, 230, "Title"],
Cell[1688, 44, 376, 6, 74, "Text"],
Cell[2067, 52, 171, 6, 45, "Text"],
Cell[2241, 60, 1864, 28, 387, "Text"],
Cell[4108, 90, 57385, 1260, 869, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature avpYTFgWi0Rp5DgKsHnbeR6E *)
